@@ -129,27 +129,30 @@ $(function() {
 
 
 	var show_cmd_output = function(data) {
-		var $output = $('#output');
-		$output.val('');
+		var outputEditor = GetOutputEditor();
+		outputEditor.setValue('');
 			
 		// Handle STDERR
 		if (data.stderr.length) {
-			$output.val(data.stderr + "\n");
+			outputEditor.setValuel(data.stderr + "\n");
 		}
 		
 		// Handle STDOUT
-		$output.val($output.val() + data.stdout + "\nExit code: " + data.exit);
+		outputEditor.setValue(outputEditor.getValue() + data.stdout + "\nExit code: " + data.exit);
+
+		// Show output tab
+		$('a[href="#output-tab"]').tab('show');
 	};
 	
 	var runOnPerlito5 = function(source) {
 
-		var $output = $('#output');
+		var outputEditor = GetOutputEditor();
 
 		// CORE.print prints to output tab
 		p5pkg.CORE.print = function(List__) {
 			var i;
 			for (i = 0; i < List__.length; i++) {
-				$output.val( $output.val() + p5str(List__[i]));
+				outputEditor.setValue( outputEditor.getValue() + p5str(List__[i]));
 			}
 			return true;
 		};
@@ -159,7 +162,7 @@ $(function() {
 			var i;
 			List__.push("\n");
 			for (i = 0; i < List__.length; i++) {
-				$output.val( $output.val() + p5str(List__[i]));
+				outputEditor.setValue( outputEditor.getValue() + p5str(List__[i]));
 			}
 			return true;
 		};
@@ -180,7 +183,7 @@ $(function() {
 		}
 
 		// Clear up output
-		$output.val('');
+		outputEditor.setValue('');
 
 		try {
 			// Compile Perl 5 source code into JavaScript
@@ -194,7 +197,7 @@ $(function() {
 		}
 		catch(err) {
 			// Populate error and show error in output tab
-			$output.val("Error:\n" + err + "\nCompilation aborted.\n");
+			outputEditor.setValue("Error:\n" + err + "\nCompilation aborted.\n");
 		}
 
 		// Show output tab
@@ -203,13 +206,13 @@ $(function() {
 	};
 
 	var runOnPerlito6 = function(source) {
-		var $output = $('#output');
+		var outputEditor = GetOutputEditor();
 		window.print = function(s) {
-			$output.val($output.val() + s + "\n");
+			outputEditor.setValue(outputEditor.getValue() + "\n");
 		}
 		var ast;
 		var match;
-		$output.val('');
+		outputEditor.setValue('');
 		try {
 			// compilation unit
 			match = Perlito6$Grammar.exp_stmts(source, 0);
@@ -220,7 +223,7 @@ $(function() {
 			eval(ast.emit_javascript());
 		} catch(err) {
 			// Show error in output tab
-			$output.val("Error:\n" + perl(err) + "\nCompilation aborted.\n");
+			outputEditor.setValue("Error:\n" + perl(err) + "\nCompilation aborted.\n");
 		}
 
 		// Show output tab
